@@ -23,12 +23,12 @@ List::BinarySearch - Binary Search a sorted list or array.
 
 =head1 VERSION
 
-Version 0.01_002
+Version 0.01_003
 Developer's Release
 
 =cut
 
-our $VERSION = '0.01_002';
+our $VERSION = '0.01_003';
 $VERSION = eval $VERSION;    ## no critic (eval,version)
 
 =head1 SYNOPSIS
@@ -157,10 +157,13 @@ element is found, undef is returned.
 
 sub bsearch_array {
     my ( $aref, $target, $code ) = @_;
-    $code //=
-        looks_like_number($target)
-        ? sub { $_[0] <=> $_[1] }
-        : sub { $_[0] cmp $_[1] };
+
+    if( ! defined( $code ) ) {
+        $code =
+            looks_like_number($target)
+            ? sub { $_[0] <=> $_[1] }
+            : sub { $_[0] cmp $_[1] };
+    }
 
     my $min = 0;
     my $max = $#{$aref};
